#a!/usr/bin/env python
"""Tests for `pep582` package."""


import unittest
import tempfile
import os


class TestPep582(unittest.TestCase):
    """Tests for `pep582` package."""

    def setUp(self):
        """Set up test fixtures, if any."""
        os.chdir(tempfile.mkdtemp())
        print(os.getcwd())
        os.mkdir('__pypackages__')

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_pip_install(self):
        """Test pip install."""
        os.system('pip install pythonloc')
        self.assertEqual(os.system('test -e __pypackages__/*/lib/pythonloc/'), 0)  # assuming we are on unix, sorry

    def test_import_module(self):
        """Test import module."""
        os.system('pip install pythonloc')
        import pythonloc
        self.assertTrue(pythonloc.__file__.startswith('__pypackages__'))



import site, os, sys

if not hasattr(site, 'pep582'):
    try:
        with open(site.__file__, 'a') as f:
            f.write("from pep582 import site")
        print('{} succesfully patched'.format(site.__file__))
        print('try creating __pypackages__ in some directory')
        print('pip install inside that directory would install into __pypackages__ by default')
        print('good luck!')
    except PermissionError:
        os.execvp(sys.executable, ['sudo']+sys.argv)
else:
    print('{} already patched'.format(site.__file__))




import os, sys


PEP582 = True

def load_pypackages():

    if os.path.exists('__pypackages__'):
        lib = '__pypackages__/{}.{}/lib'.format(sys.version_info.major, sys.version_info.minor)
        if not os.path.exists(lib):
            os.makedirs(lib)
        sys.path.insert(0, lib)
        if 'pip' in sys.argv or sys.argv[0].endswith('pip'):
            if 'install' in sys.argv and ('-t' not in sys.argv and '--target' not in sys.argv):
                sys.argv.extend(['-t', lib])

